==> haskell-bytestring-tree-builder-0.2.7.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.1
id: bytestring-tree-builder-0.2.7.1-BFhYTBhILIPGbD9qiPflK6
key: bytestring-tree-builder-0.2.7.1-BFhYTBhILIPGbD9qiPflK6
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
abi: c562b7a25c39e352a717103b7d8a4ad6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bytestring-tree-builder-0.2.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/bytestring-tree-builder-0.2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/bytestring-tree-builder-0.2.7.1
hs-libraries: HSbytestring-tree-builder-0.2.7.1-BFhYTBhILIPGbD9qiPflK6
depends:
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q bytestring-0.10.8.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=c739600aa012ae17eb506df1a043419b
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=208073fa5c5f239d647d4a6aa5951c23
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.1
id: bytestring-tree-builder-0.2.7.1-9VHHZpVo7kMEoizKw31ENg
key: bytestring-tree-builder-0.2.7.1-9VHHZpVo7kMEoizKw31ENg
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
abi: 3504a13cf63e1a52a4378ac7db24a4db
exposed: True
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
import-dirs: /usr/lib/ghc-8.4.2/site-local/bytestring-tree-builder-0.2.7.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/bytestring-tree-builder-0.2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/bytestring-tree-builder-0.2.7.1
hs-libraries: HSbytestring-tree-builder-0.2.7.1-9VHHZpVo7kMEoizKw31ENg
depends:
    semigroups-0.18.4-8TzSEFpYt1WDcfY361NEhv bytestring-0.10.8.2
    text-1.2.3.0 base-prelude-1.2.1-JzBjPH3Uj6PG2FHcpheouW
    base-4.11.1.0
abi-depends: semigroups-0.18.4-8TzSEFpYt1WDcfY361NEhv=de35bd6c21af2947fea51000f88c89bb
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             base-prelude-1.2.1-JzBjPH3Uj6PG2FHcpheouW=961a5f7519ccf89df00787dfcc2916e0
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
